@@ -53,7 +53,7 @@ class MicroblogConfig(ConfigParser):
                 print('Error in the interval setting')
                 sys.exit(1)
             try:
-                config['shortener'] = self.get('global','shortener').strip()
+                config['shortener'] = self.get(section,'shortener').strip()
             except NoOptionError:
                 config['shortener'] = 'tinyurl'
 
