@@ -37,15 +37,14 @@ class Microblog(object):
         lastread = self.rss.getlastRead()
         if not lastread:
             log.info ("There's no record of previous update on " + self.alias)
-            log.info ('new items to update:' + str(self.items))
+            log.info ('new items to update: ' + str(self.items))
             self.postIt(reversed(self.rss.feed['items'][:self.items]))
         else:
-            log.info ('last ' + self.alias + ' update time: ' + time.strftime("%Y-%m-%d %H:%M:%S",lastread))
             try:
                 lista = [item for item in self.rss.feed['items'] if item['published_parsed'] > lastread]
             except:
                 lista = [item for item in self.rss.feed['items'] if item['updated_parsed'] > lastread]
-            log.info ('items to update:' + str(len(lista)))
+            log.info ('items to update: ' + str(len(lista)))
             self.postIt(reversed(lista[:self.items]))
 
     def postIt(self, items):
@@ -56,7 +55,8 @@ class Microblog(object):
                     short_address = self.shortener.short(it["link"])	   
                 except (ShortenerException):
                     continue
-                txt = it["title"][0:114] + " " + short_address
+		txt_size = 140 - (len(short_address)+1)
+                txt = it["title"][0:txt_size] + " " + short_address
             elif self.mode == 'text':
                 try:
                     txt = self.strip_tags(it.content[0].value)[0:140]
@@ -71,11 +71,12 @@ class Microblog(object):
                 time.sleep(5)
 
             except (BadStatusLine, HTTPError, URLError), e:
-#                try:
-                resp = simplejson.loads(e.read())
-                if resp['error'] == 'Status is a duplicate.':
-                    self.rss.updateLastRead(it)                        
-#                except:
+                try:
+                    resp = simplejson.loads(e.read())
+                    log.debug(resp['error'])
+                    if resp['error'] == 'Status is a duplicate.':
+                        self.rss.updateLastRead(it)                        
+                except:
                     pass
                 #lets try in the next time
                 continue
